@@ -61,14 +61,13 @@ class PythonSearchCli:
         self.configuration = configuration
         self.run_key = EntryRunner(self.configuration).run
 
-    @notify_exception()
     def search(self):
         """
         Opens the Search UI. Main entrypoint of the application
         """
         FzfInKitty(self.configuration).run()
 
-
+    @notify_exception()
     def edit_main(self):
         """Edit the main script"""
         from python_search.entry_capture.edit_content import EditKey
@@ -82,10 +81,10 @@ class PythonSearchCli:
         return RegisterNew(self.configuration)
 
     def edit_key(self, entry_str):
+        """Opens the key in the source code using the IDE specified in the config, defaults to vim"""
         from python_search.entry_capture.edit_content import EditKey
 
-
-        result =  EditKey(self.configuration).edit_key(entry_str, dry_run=False)
+        result = EditKey(self.configuration).edit_key(entry_str, dry_run=False)
         key = entry_str.split(":")[0]
         LogRunPerformedClient().send(
             RunPerformed(key=key, query_input="", shortcut=False)
@@ -113,7 +112,7 @@ class PythonSearchCli:
         from python_search.apps.clipboard import Clipboard
 
         key = entry_str.split(":")[0]
-        Clipboard().set_content(key)
+        Clipboard().set_content(key, enable_notifications=True)
         LogRunPerformedClient().send(
             RunPerformed(key=key, query_input="", shortcut=False)
         )
@@ -129,7 +128,6 @@ class PythonSearchCli:
 
         result = EditKey(self.configuration).search_entries_directory(entry_str)
 
-
         if entry_str.split(":"):
             key = entry_str.split(":")[0]
             LogRunPerformedClient().send(
